==> x-cart-5.3.5.8-en.tgz: xcart/classes/XLite/Model/Notification.php <==
<?php
// vim: set ts=4 sw=4 sts=4 et:

/**
 * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
 * See https://www.x-cart.com/license-agreement.html for license details.
 */

namespace XLite\Model;

/**
 * Membership
 *
 * @Entity
 * @Table (name="notifications")
 */
class Notification extends \XLite\Model\Base\I18n
{
    /**
     * Notification templates directory
     *
     * @var string
     *
     * @Id
     * @Column (type="string", length=255, unique=true)
     */
    protected $templatesDirectory = '';

    /**
     * Is available for admin
     *
     * @var boolean
     *
     * @Column (type="boolean")
     */
    protected $availableForAdmin = false;

    /**
     * Is available for admin
     *
     * @var boolean
     *
     * @Column (type="boolean")
     */
    protected $availableForCustomer = false;

    /**
     * Is available for admin
     *
     * @var boolean
     *
     * @Column (type="boolean")
     */
    protected $enabledForAdmin = false;

    /**
     * Is available for admin
     *
     * @var boolean
     *
     * @Column (type="boolean")
     */
    protected $enabledForCustomer = false;

    /**
     * Is header enabled for admin
     *
     * @var boolean
     *
     * @Column (type="boolean")
     */
    protected $adminHeaderEnabled = true;

    /**
     * Is greeting enabled for admin
     *
     * @var boolean
     *
     * @Column (type="boolean")
     */
    protected $adminGreetingEnabled = true;

    /**
     * Is signature enabled for admin
     *
     * @var boolean
     *
     * @Column (type="boolean")
     */
    protected $adminSignatureEnabled = true;

    /**
     * Is header enabled for customer
     *
     * @var boolean
     *
     * @Column (type="boolean")
     */
    protected $customerHeaderEnabled = true;

    /**
     * Is greeting enabled for customer
     *
     * @var boolean
     *
     * @Column (type="boolean")
     */
    protected $customerGreetingEnabled = true;

    /**
     * Is signature enabled for customer
     *
     * @var boolean
     *
     * @Column (type="boolean")
     */
    protected $customerSignatureEnabled = true;

    /**
     * A position of the notification among other notifications
     *
     * @var integer
     *
     * @Column (type="integer", options={"default" : 0})
     */
    protected $position = 0;

    /**
     * Set templatesDirectory
     *
     * @param string $templatesDirectory
     *
     * @return Notification
     */
    public function setTemplatesDirectory($templatesDirectory)
    {
        $this->templatesDirectory = $templatesDirectory;

        return $this;
    }

    /**
     * Get templatesDirectory
     *
     * @return string
     */
    public function getTemplatesDirectory()
    {
        return $this->templatesDirectory;
    }

    /**
     * Set availableForAdmin
     *
     * @param boolean $availableForAdmin
     *
     * @return Notification
     */
    public function setAvailableForAdmin($availableForAdmin)
    {
        $this->availableForAdmin = $availableForAdmin;

        return $this;
    }

    /**
     * Get availableForAdmin
     *
     * @return boolean
     */
    public function getAvailableForAdmin()
    {
        return $this->availableForAdmin;
    }

    /**
     * Set availableForCustomer
     *
     * @param boolean $availableForCustomer
     *
     * @return Notification
     */
    public function setAvailableForCustomer($availableForCustomer)
    {
        $this->availableForCustomer = $availableForCustomer;

        return $this;
    }

    /**
     * Get availableForCustomer
     *
     * @return boolean
     */
    public function getAvailableForCustomer()
    {
        return $this->availableForCustomer;
    }

    /**
     * Set enabledForAdmin
     *
     * @param boolean $enabledForAdmin
     *
     * @return Notification
     */
    public function setEnabledForAdmin($enabledForAdmin)
    {
        $this->enabledForAdmin = $enabledForAdmin;

        return $this;
    }

    /**
     * Get enabledForAdmin
     *
     * @return boolean
     */
    public function getEnabledForAdmin()
    {
        return $this->enabledForAdmin;
    }

    /**
     * Set enabledForCustomer
     *
     * @param boolean $enabledForCustomer
     *
     * @return Notification
     */
    public function setEnabledForCustomer($enabledForCustomer)
    {
        $this->enabledForCustomer = $enabledForCustomer;

        return $this;
    }

    /**
     * Get enabledForCustomer
     *
     * @return boolean
     */
    public function getEnabledForCustomer()
    {
        return $this->enabledForCustomer;
    }

    /**
     * @return boolean
     */
    public function getAdminHeaderEnabled()
    {
        return $this->adminHeaderEnabled;
    }

    /**
     * @param boolean $adminHeaderEnabled
     */
    public function setAdminHeaderEnabled($adminHeaderEnabled)
    {
        $this->adminHeaderEnabled = $adminHeaderEnabled;
    }

    /**
     * @return boolean
     */
    public function getAdminGreetingEnabled()
    {
        return $this->adminGreetingEnabled;
    }

    /**
     * @param boolean $adminGreetingEnabled
     */
    public function setAdminGreetingEnabled($adminGreetingEnabled)
    {
        $this->adminGreetingEnabled = $adminGreetingEnabled;
    }

    /**
     * @return boolean
     */
    public function getAdminSignatureEnabled()
    {
        return $this->adminSignatureEnabled;
    }

    /**
     * @param boolean $adminSignatureEnabled
     */
    public function setAdminSignatureEnabled($adminSignatureEnabled)
    {
        $this->adminSignatureEnabled = $adminSignatureEnabled;
    }

    /**
     * @return boolean
     */
    public function getCustomerHeaderEnabled()
    {
        return $this->customerHeaderEnabled;
    }

    /**
     * @param boolean $customerHeaderEnabled
     */
    public function setCustomerHeaderEnabled($customerHeaderEnabled)
    {
        $this->customerHeaderEnabled = $customerHeaderEnabled;
    }

    /**
     * @return boolean
     */
    public function getCustomerGreetingEnabled()
    {
        return $this->customerGreetingEnabled;
    }

    /**
     * @param boolean $customerGreetingEnabled
     */
    public function setCustomerGreetingEnabled($customerGreetingEnabled)
    {
        $this->customerGreetingEnabled = $customerGreetingEnabled;
    }

    /**
     * @return boolean
     */
    public function getCustomerSignatureEnabled()
    {
        return $this->customerSignatureEnabled;
    }

    /**
     * @param boolean $customerSignatureEnabled
     */
    public function setCustomerSignatureEnabled($customerSignatureEnabled)
    {
        $this->customerSignatureEnabled = $customerSignatureEnabled;
    }

    /**
     * @return int
     */
    public function getPosition()
    {
        return $this->position;
    }

    /**
     * @param int $position
     * @return $this
     */
    public function setPosition($position)
    {
        $this->position = $position;
        return $this;
    }
}

==> x-cart-5.4.0.8-en.tgz: xcart/classes/XLite/Model/Notification.php <==
<?php
// vim: set ts=4 sw=4 sts=4 et:

/**
 * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
 * See https://www.x-cart.com/license-agreement.html for license details.
 */

namespace XLite\Model;

/**
 * Membership
 *
 * @Entity
 * @Table (name="notifications")
 */
class Notification extends \XLite\Model\Base\I18n
{
    /**
     * Notification templates directory
     *
     * @var string
     *
     * @Id
     * @Column (type="string", length=255, unique=true)
     */
    protected $templatesDirectory = '';

    /**
     * Is available for admin
     *
     * @var boolean
     *
     * @Column (type="boolean")
     */
    protected $availableForAdmin = false;

    /**
     * Is available for admin
     *
     * @var boolean
     *
     * @Column (type="boolean")
     */
    protected $availableForCustomer = false;

    /**
     * Is available for admin
     *
     * @var boolean
     *
     * @Column (type="boolean")
     */
    protected $enabledForAdmin = false;

    /**
     * Is available for admin
     *
     * @var boolean
     *
     * @Column (type="boolean")
     */
    protected $enabledForCustomer = false;

    /**
     * Is header enabled for admin
     *
     * @var boolean
     *
     * @Column (type="boolean")
     */
    protected $adminHeaderEnabled = true;

    /**
     * Is greeting enabled for admin
     *
     * @var boolean
     *
     * @Column (type="boolean")
     */
    protected $adminGreetingEnabled = true;

    /**
     * Is signature enabled for admin
     *
     * @var boolean
     *
     * @Column (type="boolean")
     */
    protected $adminSignatureEnabled = true;

    /**
     * Is header enabled for customer
     *
     * @var boolean
     *
     * @Column (type="boolean")
     */
    protected $customerHeaderEnabled = true;

    /**
     * Is greeting enabled for customer
     *
     * @var boolean
     *
     * @Column (type="boolean")
     */
    protected $customerGreetingEnabled = true;

    /**
     * Is signature enabled for customer
     *
     * @var boolean
     *
     * @Column (type="boolean")
     */
    protected $customerSignatureEnabled = true;

    /**
     * A position of the notification among other notifications
     *
     * @var integer
     *
     * @Column (type="integer", options={"default" : 0})
     */
    protected $position = 0;

    /**
     * Is signature editable
     *
     * @var boolean
     *
     * @Column (type="boolean")
     */
    protected $editable = false;

    /**
     * Set templatesDirectory
     *
     * @param string $templatesDirectory
     *
     * @return Notification
     */
    public function setTemplatesDirectory($templatesDirectory)
    {
        $this->templatesDirectory = $templatesDirectory;

        return $this;
    }

    /**
     * Get templatesDirectory
     *
     * @return string
     */
    public function getTemplatesDirectory()
    {
        return $this->templatesDirectory;
    }

    /**
     * Set availableForAdmin
     *
     * @param boolean $availableForAdmin
     *
     * @return Notification
     */
    public function setAvailableForAdmin($availableForAdmin)
    {
        $this->availableForAdmin = $availableForAdmin;

        return $this;
    }

    /**
     * Get availableForAdmin
     *
     * @return boolean
     */
    public function getAvailableForAdmin()
    {
        return $this->availableForAdmin;
    }

    /**
     * Set availableForCustomer
     *
     * @param boolean $availableForCustomer
     *
     * @return Notification
     */
    public function setAvailableForCustomer($availableForCustomer)
    {
        $this->availableForCustomer = $availableForCustomer;

        return $this;
    }

    /**
     * Get availableForCustomer
     *
     * @return boolean
     */
    public function getAvailableForCustomer()
    {
        return $this->availableForCustomer;
    }

    /**
     * Set enabledForAdmin
     *
     * @param boolean $enabledForAdmin
     *
     * @return Notification
     */
    public function setEnabledForAdmin($enabledForAdmin)
    {
        $this->enabledForAdmin = $enabledForAdmin;

        return $this;
    }

    /**
     * Get enabledForAdmin
     *
     * @return boolean
     */
    public function getEnabledForAdmin()
    {
        return $this->enabledForAdmin;
    }

    /**
     * Set enabledForCustomer
     *
     * @param boolean $enabledForCustomer
     *
     * @return Notification
     */
    public function setEnabledForCustomer($enabledForCustomer)
    {
        $this->enabledForCustomer = $enabledForCustomer;

        return $this;
    }

    /**
     * Get enabledForCustomer
     *
     * @return boolean
     */
    public function getEnabledForCustomer()
    {
        return $this->enabledForCustomer;
    }

    /**
     * @return boolean
     */
    public function getAdminHeaderEnabled()
    {
        return $this->adminHeaderEnabled;
    }

    /**
     * @param boolean $adminHeaderEnabled
     */
    public function setAdminHeaderEnabled($adminHeaderEnabled)
    {
        $this->adminHeaderEnabled = $adminHeaderEnabled;
    }

    /**
     * @return boolean
     */
    public function getAdminGreetingEnabled()
    {
        return $this->adminGreetingEnabled;
    }

    /**
     * @param boolean $adminGreetingEnabled
     */
    public function setAdminGreetingEnabled($adminGreetingEnabled)
    {
        $this->adminGreetingEnabled = $adminGreetingEnabled;
    }

    /**
     * @return boolean
     */
    public function getAdminSignatureEnabled()
    {
        return $this->adminSignatureEnabled;
    }

    /**
     * @param boolean $adminSignatureEnabled
     */
    public function setAdminSignatureEnabled($adminSignatureEnabled)
    {
        $this->adminSignatureEnabled = $adminSignatureEnabled;
    }

    /**
     * @return boolean
     */
    public function getCustomerHeaderEnabled()
    {
        return $this->customerHeaderEnabled;
    }

    /**
     * @param boolean $customerHeaderEnabled
     */
    public function setCustomerHeaderEnabled($customerHeaderEnabled)
    {
        $this->customerHeaderEnabled = $customerHeaderEnabled;
    }

    /**
     * @return boolean
     */
    public function getCustomerGreetingEnabled()
    {
        return $this->customerGreetingEnabled;
    }

    /**
     * @param boolean $customerGreetingEnabled
     */
    public function setCustomerGreetingEnabled($customerGreetingEnabled)
    {
        $this->customerGreetingEnabled = $customerGreetingEnabled;
    }

    /**
     * @return boolean
     */
    public function getCustomerSignatureEnabled()
    {
        return $this->customerSignatureEnabled;
    }

    /**
     * @param boolean $customerSignatureEnabled
     */
    public function setCustomerSignatureEnabled($customerSignatureEnabled)
    {
        $this->customerSignatureEnabled = $customerSignatureEnabled;
    }

    /**
     * @return int
     */
    public function getPosition()
    {
        return $this->position;
    }

    /**
     * @param int $position
     * @return $this
     */
    public function setPosition($position)
    {
        $this->position = $position;
        return $this;
    }

    /**
     * Return Editable
     *
     * @return bool
     */
    public function isEditable()
    {
        return $this->editable;
    }

    /**
     * Set Editable
     *
     * @param bool $editable
     *
     * @return $this
     */
    public function setEditable($editable)
    {
        $this->editable = (boolean)$editable;
        return $this;
    }
}
